@@ -6,6 +6,8 @@
 #define MPU_MAX_FACTORS 64
 
 extern int factor(UV n, UV *factors);
+extern int factor_exp(UV n, UV *factors, UV* exponents);
+extern UV  divisor_sum(UV n, UV k);
 
 extern int trial_factor(UV n, UV *factors, UV maxtrial);
 
@@ -16,8 +18,10 @@ extern int prho_factor(UV n, UV *factors, UV maxrounds);
 extern int pminus1_factor(UV n, UV *factors, UV B1, UV B2);
 extern int pplus1_factor(UV n, UV *factors, UV B);
 extern int squfof_factor(UV n, UV *factors, UV rounds);
-extern int racing_squfof_factor(UV n, UV *factors, UV rounds);
 
-extern UV _XS_divisor_sum(UV n, UV k);
+extern UV* _divisor_list(UV n, UV *num_divisors);
+
+extern UV dlp_trial(UV a, UV g, UV p, UV maxrounds);
+extern UV dlp_prho(UV a, UV g, UV p, UV maxrounds);
 
 #endif
