@@ -10,7 +10,6 @@ use Carp qw/carp croak confess/;
 package Math::Prime::Util;
 
 *_validate_num = \&Math::Prime::Util::PP::_validate_num;
-*_validate_integer = \&Math::Prime::Util::PP::_validate_integer;
 *_prime_memfreeall = \&Math::Prime::Util::PP::_prime_memfreeall;
 *prime_memfree  = \&Math::Prime::Util::PP::prime_memfree;
 *prime_precalc  = \&Math::Prime::Util::PP::prime_precalc;
@@ -106,50 +105,32 @@ sub prime_count_approx {
   _validate_positive_integer($n);
   return Math::Prime::Util::PP::prime_count_approx($n);
 }
-sub twin_prime_count {
-  my($low,$high) = @_;
-  if (scalar @_ > 1) {
-    _validate_positive_integer($low);
-    _validate_positive_integer($high);
-  } else {
-    ($low,$high) = (2, $low);
-    _validate_positive_integer($high);
-  }
-  return Math::Prime::Util::PP::twin_prime_count($low,$high);
-}
-sub twin_prime_count_approx {
-  my($n) = @_;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::twin_prime_count_approx($n);
-}
-sub nth_twin_prime {
-  my($n) = @_;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::nth_twin_prime($n);
-}
-sub nth_twin_prime_approx {
-  my($n) = @_;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::nth_twin_prime_approx($n);
-}
 
 
-*is_prime       = \&Math::Prime::Util::PP::is_prime;
-*is_prob_prime  = \&Math::Prime::Util::PP::is_prob_prime;
-*is_bpsw_prime  = \&Math::Prime::Util::PP::is_bpsw_prime;
-
+sub is_prime {
+  my($n) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_prime($n);
+}
+sub is_prob_prime {
+  my($n) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_prob_prime($n);
+}
 sub is_pseudoprime {
   my($n, $base) = @_;
   return 0 if defined $n && int($n) < 0;
   _validate_positive_integer($n);
-  _validate_positive_integer($base) if defined $base;
+  _validate_positive_integer($base);
   return Math::Prime::Util::PP::is_pseudoprime($n, $base);
 }
 sub is_strong_pseudoprime {
   my($n, @bases) = @_;
   return 0 if defined $n && int($n) < 0;
   _validate_positive_integer($n);
-  croak "No bases given to is_strong_pseudoprime" unless @bases;
+  croak "No bases given to miller_rabin" unless @bases;
   return Math::Prime::Util::PP::is_strong_pseudoprime($n, @bases);
 }
 sub is_lucas_pseudoprime {
@@ -178,19 +159,6 @@ sub is_almost_extra_strong_lucas_pseudoprime {
   } else                  { $increment = 1; }
   return Math::Prime::Util::PP::is_almost_extra_strong_lucas_pseudoprime($n, $increment);
 }
-sub is_perrin_pseudoprime {
-  my($n) = @_;
-  return 0 if defined $n && int($n) < 0;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::is_perrin_pseudoprime($n);
-}
-sub is_frobenius_pseudoprime {
-  my($n, $P, $Q) = @_;
-  return 0 if defined $n && int($n) < 0;
-  _validate_positive_integer($n);
-  # TODO: validate P & Q
-  return Math::Prime::Util::PP::is_frobenius_pseudoprime($n, $P, $Q);
-}
 sub is_frobenius_underwood_pseudoprime {
   my($n) = @_;
   return 0 if defined $n && int($n) < 0;
@@ -215,19 +183,6 @@ sub kronecker {
   return Math::Prime::Util::PP::kronecker(@_);
 }
 
-sub factorial {
-  my($n) = @_;
-  _validate_integer($n);
-  return Math::Prime::Util::PP::factorial($n);
-}
-
-sub binomial {
-  my($n, $k) = @_;
-  _validate_integer($n);
-  _validate_integer($k);
-  return Math::Prime::Util::PP::binomial($n, $k);
-}
-
 sub znorder {
   my($a, $n) = @_;
   _validate_positive_integer($a);
@@ -312,6 +267,14 @@ sub pminus1_factor {
   Math::Prime::Util::PP::pminus1_factor($n, $B1, $B2);
 }
 *pplus1_factor = \&pminus1_factor;
+sub ecm_factor {
+  my($n, $B1, $B2, $ncurves) = @_;
+  _validate_positive_integer($n);
+  _validate_positive_integer($B1) if defined $B1;
+  _validate_positive_integer($B2) if defined $B2;
+  _validate_positive_integer($ncurves) if defined $ncurves;
+  Math::Prime::Util::PP::ecm_factor($n, $B1, $B2, $ncurves);
+}
 
 sub divisors {
   my($n) = @_;
@@ -327,56 +290,10 @@ sub divisor_sum {
 }
 
 sub gcd {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::gcd(@v);
+  return Math::Prime::Util::PP::gcd(@_);
 }
 sub lcm {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::lcm(@v);
-}
-sub gcdext {
-  my($a,$b) = @_;
-  _validate_integer($a);
-  _validate_integer($b);
-  return Math::Prime::Util::PP::gcdext($a,$b);
-}
-sub chinese {
-  # TODO: make sure we're not modding their data
-  foreach my $aref (@_) {
-    die "chinese arguments are two-element array references"
-      unless ref($aref) eq 'ARRAY' && scalar @$aref == 2;
-    _validate_integer($aref->[0]);
-    _validate_integer($aref->[1]);
-  }
-  return Math::Prime::Util::PP::chinese(@_);
-}
-sub vecsum {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::vecsum(@v);
-}
-sub vecprod {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::vecprod(@v);
-}
-sub vecmin {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::vecmin(@v);
-}
-sub vecmax {
-  my(@v) = @_;
-  _validate_integer($_) for @v;
-  return Math::Prime::Util::PP::vecmax(@v);
-}
-sub invmod {
-  my ($a, $n) = @_;
-  _validate_integer($a);
-  _validate_integer($n);
-  return Math::Prime::Util::PP::invmod($a,$n);
+  return Math::Prime::Util::PP::lcm(@_);
 }
 
 sub legendre_phi {
@@ -397,28 +314,6 @@ sub chebyshev_psi {
   return Math::Prime::Util::PP::chebyshev_psi($n);
 }
 
-sub is_power {
-  my($n, $a) = @_;
-  return 0 if defined $n && $n < 0;
-  _validate_positive_integer($n);
-  _validate_positive_integer($a) if defined $a;
-  return Math::Prime::Util::PP::is_power($n, $a);
-}
-sub valuation {
-  my($n, $k) = @_;
-  $n = -$n if defined $n && $n < 0;
-  $k = -$k if defined $k && $k < 0;
-  _validate_positive_integer($n);
-  _validate_positive_integer($k);
-  return Math::Prime::Util::PP::valuation($n, $k);
-}
-
-sub Pi {
-  my($digits) = @_;
-  _validate_positive_integer($digits) if defined $digits;
-  return Math::Prime::Util::PP::Pi($digits);
-}
-
 #############################################################################
 
 sub forprimes (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
@@ -456,26 +351,6 @@ sub forcomposites(&$;$) { ## no critic qw(ProhibitSubroutinePrototypes)
   }
 }
 
-sub foroddcomposites(&$;$) { ## no critic qw(ProhibitSubroutinePrototypes)
-  my($sub, $beg, $end) = @_;
-  if (!defined $end) { $end = $beg; $beg = 9; }
-  _validate_num($beg) || _validate_positive_integer($beg);
-  _validate_num($end) || _validate_positive_integer($end);
-  $beg = 9 if $beg < 9;
-  $beg++ unless $beg & 1;
-  $end = Math::BigInt->new(''.~0) if ref($end) ne 'Math::BigInt' && $end == ~0;
-  {
-    my $pp;
-    local *_ = \$pp;
-    for ( ; $beg <= $end ; $beg += 2 ) {
-      if (!is_prime($beg)) {
-        $pp = $beg;
-        $sub->();
-      }
-    }
-  }
-}
-
 sub fordivisors (&$) {    ## no critic qw(ProhibitSubroutinePrototypes)
   my($sub, $n) = @_;
   _validate_num($n) || _validate_positive_integer($n);
@@ -490,16 +365,6 @@ sub fordivisors (&$) {    ## no critic qw(ProhibitSubroutinePrototypes)
   }
 }
 
-sub forpart (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
-  Math::Prime::Util::PP::forpart(@_);
-}
-sub forcomb (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
-  Math::Prime::Util::PP::forcomb(@_);
-}
-sub forperm (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
-  Math::Prime::Util::PP::forperm(@_);
-}
-
 1;
 
 __END__
